@@ -92,6 +92,8 @@ async def request(
                             raise LookupError('Not found')
                         case HTTPStatus.BAD_REQUEST:
                             raise ValueError('Bad request')
+                        case HTTPStatus.TOO_MANY_REQUESTS:
+                            raise InterruptedError('Too many requests')
                         case _:
                             response.raise_for_status()
         else:
@@ -108,6 +110,8 @@ async def request(
                     await _store_response_for_audit(response, audit_name, uri_path, method, request_id)
 
                 yield response
+    except client_exceptions.ClientConnectorError as e:
+        raise ConnectionRefusedError('Cient connection error') from e
     except client_exceptions.ClientOSError as e:
         if e.errno == 32:
             raise ConnectionResetError('Broken pipe') from e
